@@ -87,7 +87,11 @@ class Recipe(GenericBaseRecipe):
       'haproxy-listen-snippet.cfg.in')
     server_snippet = ""
     ip = self.options['ip']
-    server_check_path = self.options['server-check-path']
+    server_check_path = self.options.get('server-check-path', None)
+    if server_check_path:
+      httpchk = 'option httpchk GET %s' % server_check_path
+    else:
+      httpchk = ''
     # FIXME: maxconn must be provided per-backend, not globally
     maxconn = self.options['maxconn']
     i = 0
@@ -97,7 +101,7 @@ class Recipe(GenericBaseRecipe):
           'name': name,
           'ip': ip,
           'port': port,
-          'server_check_path': server_check_path,
+          'httpchk': httpchk,
         })
       for address in backend_list:
         i += 1
